@@ -67,5 +67,5 @@ class SanitizedTextField(models.TextField):
 
 if 'south' in settings.INSTALLED_APPS:
     from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^sanitizer\.models\.SanitizedCharField"])
-    add_introspection_rules([], ["^sanitizer\.models\.SanitizedTextField"])
+    add_introspection_rules([], ["^django_html_cleaner\.models\.SanitizedCharField"])
+    add_introspection_rules([], ["^django_html_cleaner\.models\.SanitizedTextField"])
