@@ -5,4 +5,4 @@ from django.db import models
 class Post(models.Model):
     id = models.IntegerField(primary_key=True)
     title = SanitizedCharField(max_length=200)
-    body = SanitizedTextField()
+    body = SanitizedTextField(null=True,blank=True)
